@@ -1,9 +1,9 @@
 package Sort::Sub::pod_section_ala_perlancar;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-06-04'; # DATE
+our $DATE = '2021-08-06'; # DATE
 our $DIST = 'Sort-SubBundle-PERLANCAR'; # DIST
-our $VERSION = '0.088'; # VERSION
+our $VERSION = '0.089'; # VERSION
 
 use 5.010001;
 use strict;
@@ -81,7 +81,9 @@ our $SORT_SPEC = [
     qr/^AUTHORS?/,
     qr/^ORIGINAL AUTHORS?/,
 
-    'CONTRIBUTORS',
+    'CONTRIBUTOR', 'CONTRIBUTORS',
+
+    'CONTRIBUTING',
 
     'COPYRIGHT AND LICENSE', 'ORIGINAL COPYRIGHT AND LICENSE',
     'COPYRIGHT', 'ORIGINAL COPYRIGHT',
@@ -121,7 +123,7 @@ Sort::Sub::pod_section_ala_perlancar - Sort POD sections (headings) PERLANCAR-st
 
 =head1 VERSION
 
-This document describes version 0.088 of Sort::Sub::pod_section_ala_perlancar (from Perl distribution Sort-SubBundle-PERLANCAR), released on 2021-06-04.
+This document describes version 0.089 of Sort::Sub::pod_section_ala_perlancar (from Perl distribution Sort-SubBundle-PERLANCAR), released on 2021-08-06.
 
 =head1 SYNOPSIS
 
@@ -194,7 +196,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
